==> jc-1.4.0.tar.gz: soot/jimple/toolkits/scalar/Evaluator.h <==
// public class soot.jimple.toolkits.scalar.Evaluator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f99a5f3c919faa6a soot_jimple_toolkits_scalar_Evaluator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_scalar_Evaluator_H_
#define _JC_soot_jimple_toolkits_scalar_Evaluator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_Evaluator$sub_refs	_jc_soot_jimple_toolkits_scalar_Evaluator$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_Evaluator$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_Evaluator$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_Evaluator$refs	_jc_soot_jimple_toolkits_scalar_Evaluator$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_Evaluator$nonrefs	_jc_soot_jimple_toolkits_scalar_Evaluator$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_Evaluator$object	_jc_soot_jimple_toolkits_scalar_Evaluator$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_Evaluator$vmethods	_jc_soot_jimple_toolkits_scalar_Evaluator$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_Evaluator$vtable	_jc_soot_jimple_toolkits_scalar_Evaluator$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_Evaluator$vtype	_jc_soot_jimple_toolkits_scalar_Evaluator$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_Evaluator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_Evaluator$object *);

// Static methods
extern struct _jc_object *_jc_soot_jimple_toolkits_scalar_Evaluator$method$getConstantValueOf$118cbcc06cd1a4e8(_jc_env *, struct _jc_object *);
extern jboolean _jc_soot_jimple_toolkits_scalar_Evaluator$method$isValueConstantValued$771abbdbca4351a0(_jc_env *, struct _jc_object *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_Evaluator$vmethods {
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_Evaluator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_scalar_Evaluator$vmethods	soot_jimple_toolkits_scalar_Evaluator;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_Evaluator$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_Evaluator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_Evaluator$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_Evaluator$refs {
    _jc_soot_jimple_toolkits_scalar_Evaluator$sub_refs	soot_jimple_toolkits_scalar_Evaluator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_Evaluator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_Evaluator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_scalar_Evaluator$sub_nonrefs	soot_jimple_toolkits_scalar_Evaluator;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_Evaluator$object {
	_jc_soot_jimple_toolkits_scalar_Evaluator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_Evaluator$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_Evaluator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_Evaluator$vtype _jc_soot_jimple_toolkits_scalar_Evaluator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_Evaluator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_Evaluator$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_Evaluator_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/scalar/Evaluator.h <==
// public class soot.jimple.toolkits.scalar.Evaluator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f99a5f3c919faa6a soot_jimple_toolkits_scalar_Evaluator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_scalar_Evaluator_H_
#define _JC_soot_jimple_toolkits_scalar_Evaluator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_Evaluator$sub_refs	_jc_soot_jimple_toolkits_scalar_Evaluator$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_Evaluator$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_Evaluator$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_Evaluator$refs	_jc_soot_jimple_toolkits_scalar_Evaluator$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_Evaluator$nonrefs	_jc_soot_jimple_toolkits_scalar_Evaluator$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_Evaluator$object	_jc_soot_jimple_toolkits_scalar_Evaluator$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_Evaluator$vmethods	_jc_soot_jimple_toolkits_scalar_Evaluator$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_Evaluator$vtable	_jc_soot_jimple_toolkits_scalar_Evaluator$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_Evaluator$vtype	_jc_soot_jimple_toolkits_scalar_Evaluator$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_Evaluator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_Evaluator$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_object *_jc_soot_jimple_toolkits_scalar_Evaluator$method$getConstantValueOf$118cbcc06cd1a4e8(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_scalar_Evaluator$method$isValueConstantValued$771abbdbca4351a0(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_Evaluator$vmethods {
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_Evaluator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_scalar_Evaluator$vmethods	soot_jimple_toolkits_scalar_Evaluator;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_Evaluator$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_Evaluator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_Evaluator$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_Evaluator$refs {
    _jc_soot_jimple_toolkits_scalar_Evaluator$sub_refs	soot_jimple_toolkits_scalar_Evaluator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_Evaluator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_Evaluator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_scalar_Evaluator$sub_nonrefs	soot_jimple_toolkits_scalar_Evaluator;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_Evaluator$object {
	_jc_soot_jimple_toolkits_scalar_Evaluator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_Evaluator$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_Evaluator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_Evaluator$vtype _jc_soot_jimple_toolkits_scalar_Evaluator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_Evaluator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_Evaluator$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_Evaluator_H_ */
